Struct google_groupsmigration1::Groups [−][src]
JSON response template for groups migration API.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- insert archive (response)
Fields
kind: Option<String>
The kind of insert resource this is.
response_code: Option<String>
The status of the insert request.